@@ -7,6 +7,7 @@ from mftoolbox import constants, funcs
 from selenium import webdriver
 from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 import time
+from mftoolbox.initSelenium import __browser
 
 def volatilidade(__ticker, **kwargs):
     """
@@ -58,7 +59,7 @@ def volatilidade(__ticker, **kwargs):
 
 
 
-def ultima_cotacao(__ticker, **kwargs):
+def ultimo_preco(__ticker, **kwargs):
     """
     Busca no site Tradingview.com o nome de pregão de um ativo, a última cotação, seu horário,
     ganho monetário e percentual
@@ -321,4 +322,72 @@ def cotacoes_historicas(ativo, **kwargs):
                 __cotacoes_final.append(__linha)
 
     # return "Modo pregões = " + str(__modo_pregoes), "Quantidade de registros = " + str(len(__cotacoes_final)), "Parêmetro pregões = " + str(pregoes), "Última data dos registros = " + str(__cotacoes_final[len(__cotacoes_final)-1][1]), "Parâmetro data de início = " + str(data_inicio)
-    return __cotacoes_final
\ No newline at end of file
+    return __cotacoes_final
+
+
+def volatilidade(__ativo, **kwargs):
+    '''
+    Busca no site de B3 a volatilidade de um ativo (1, 3, 6, 12, todos)
+    Args:
+        ativo: ticker do ativo
+        **kwargs:
+            meses: quantidade de meses da volatilidade. sem este argumento, padrão é 6 meses
+
+    Returns:
+        caso não seja passado o ticker do ativo (independentemente dos outros parâmetros):
+            mensagem: Ativo não pode ser ''.
+        caso o argumento meses não for 1, 3, 6, 12 ou todos:
+            mensagem: Período de {meses} mes(s) inválido.
+        caso número de parâmetros seja maior que 1:
+            mensagem: número de parâmetros inválido. Formato: volatilidade(ticker,meses=x)
+        qualquer outro erro:
+            mensagem: não foi possível carregar a volatilidade para {ativo}
+
+'''
+    if __ativo == '':
+        return "Ativo não pode ser ''"
+
+    if len(kwargs) >2:
+        return "Número de parâmetros inválido. Formato: volatilidade(ticker,meses=x)"
+    elif len(kwargs) == 0:
+        __meses = '6'
+    __param[kwargs[__item].upper()] = kwargs[__item]
+
+    try:
+        __meses = __param['MESES']
+    except:
+        __key = netxt(iter(__param))
+        return f'Parâmetro inválido: {__key}={__param[__key]}. Formato: volatilidade(ticker,meses=x)'
+
+    __url_root = 'http://bvmf.bmfbovespa.com.br/cias-listadas/volatilidade-ativos/' \
+               'ResumoVolatilidadeAtivos.aspx?metodo=padrao&periodo=xxxxxxxxxx&codigo=' + __ativo + '&idioma=pt-br'
+
+    __periodo = {}
+    __periodo['1'] = '1Mes'
+    __periodo['3'] = '3Meses'
+    __periodo['6'] = '6Meses'
+    __periodo['12'] = '1Ano'
+
+    __resultado = []
+    try:
+        if __meses = 'todos':
+            for __item in __periodo:
+                __url = __url_root.replace('xxxxxxxxxx',__periodo[str(__item)])
+                __html = __browser.page_source
+                __soup = BeautifulSoup(__html, 'lxml')
+                __td_list = __soup.find_all('td')
+                __desvio_padrao = round(float(td_list[3].text.replace(',', '.')), 2)
+                __volatilidade_anualizada = round(float(td_list[4].text.replace(',', '.')), 2)
+                __resultado.append([__desvio_padrao, __volatilidade_anualizada])
+        else
+            __url = __url_root.replace('xxxxxxxxxx', __periodo[str(__meses)])
+            __html = __browser.page_source
+            __soup = BeautifulSoup(__html, 'lxml')
+            __td_list = __soup.find_all('td')
+            __desvio_padrao = round(float(td_list[3].text.replace(',', '.')), 2)
+            __volatilidade_anualizada = round(float(td_list[4].text.replace(',', '.')), 2)
+            __resultado.append([__desvio_padrao, __volatilidade_anualizada])
+
+        return __resultado
+    except:
+        return "Não foi possível obert volatilidade."
