@@ -98,7 +98,7 @@ def ClearCache():
 
 def InitBrowser(headless=True):
     browser.close()
-    if headless = True
+    if headless == True
         __options.add_argument("headless")
     # noinspection SpellCheckingInspection
     browser = __webdriver.Chrome(options=__options, service_args=['--silent'], desired_capabilities=__caps)
